@@ -1,6 +1,6 @@
 /* ksba.h - X.509 library used by GnuPG
  * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2010, 2011
- *               2012, 2013, 2104, 2015, 2019 g10 Code GmbH
+ *               2012, 2013, 2104, 2015, 2019, 2020, 2021 g10 Code GmbH
  *
  * This file is part of KSBA.
  *
@@ -27,6 +27,7 @@
  * You should have received a copies of the GNU General Public License
  * and the GNU Lesser General Public License along with this program;
  * if not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-3.0-or-later OR GPL-2.0-or-later
  */
 
 #ifndef KSBA_H
@@ -45,11 +46,11 @@ extern "C" {
 /* The version of this header should match the one of the library.  Do
  * not use this symbol in your application; use assuan_check_version
  * instead.  */
-#define KSBA_VERSION "1.4.0"
+#define KSBA_VERSION "1.6.2"
 
 /* The version number of this header.  It may be used to handle minor
  * API incompatibilities.  */
-#define KSBA_VERSION_NUMBER 0x010400
+#define KSBA_VERSION_NUMBER 0x010602
 
 
 
@@ -124,7 +125,9 @@ typedef enum
     KSBA_CT_ENCRYPTED_DATA = 5,
     KSBA_CT_AUTH_DATA = 6,
     KSBA_CT_PKCS12 = 7,
-    KSBA_CT_SPC_IND_DATA_CTX = 8
+    KSBA_CT_SPC_IND_DATA_CTX = 8,
+    KSBA_CT_OPENPGP_KEYBLOCK = 9,
+    KSBA_CT_AUTHENVELOPED_DATA = 10
   }
 ksba_content_type_t;
 typedef ksba_content_type_t KsbaContentType _KSBA_DEPRECATED;
